==> vue-hooks-plus-1.6.2.tgz: package/lib/useUrlState/index.js <==
"use strict";
const qs = require("qs");
const vue = require("vue");
const index = require("../index");
const utils = require("../utils");
const _interopDefaultLegacy = (e) => e && typeof e === "object" && "default" in e ? e : { default: e };
const qs__default = /* @__PURE__ */ _interopDefaultLegacy(qs);
function encodeParams(value) {
  return qs__default.default.stringify(value);
}
function decodeParams(valueStr, detectNumber) {
  return qs__default.default.parse(valueStr, {
    arrayLimit: 1e4,
    decoder(str, _, charset) {
      const strWithoutPlus = str.replace(/\+/g, " ");
      if (charset === "iso-8859-1") {
        return strWithoutPlus.replace(/%[0-9a-f]{2}/gi, unescape);
      }
      if (detectNumber && /^[+-]?\d+(\.\d+)?$/.test(str)) {
        return parseFloat(str);
      }
      const keywords = {
        true: true,
        false: false,
        null: null,
        undefined: void 0
      };
      if (str in keywords) {
        return keywords[str];
      }
      try {
        return decodeURIComponent(strWithoutPlus);
      } catch (e) {
        return strWithoutPlus;
      }
    }
  });
}
function useUrlState(initialState, options) {
  var _a;
  const routerPushFn = (options == null ? void 0 : options.routerPush) ? options.routerPush : (s) => location.hash = s;
  const { localStorageKey, detectNumber = true } = options != null ? options : {};
  const [path, paramsStr] = location.hash.slice(1).split("?");
  const defaultState = (_a = utils.isFunction(initialState) ? initialState() : initialState) != null ? _a : {};
  const state = localStorageKey ? index.useLocalStorageState(localStorageKey, {
    defaultValue: defaultState
  })[0] : vue.ref(defaultState);
  if (paramsStr) {
    try {
      const paramsValue = decodeParams(paramsStr, detectNumber);
      state.value = {
        ...defaultState,
        ...state.value,
        ...paramsValue
      };
    } catch {
      state.value = defaultState;
    }
  }
  if (initialState && Object.keys(initialState).length) {
    const newState = { ...initialState };
    for (const key in newState) {
      if (key in state.value) {
        newState[key] = state.value[key];
      }
    }
    state.value = newState;
  }
  vue.watch(
    state,
    () => {
      const newParamsStr = encodeParams(state.value);
      routerPushFn(`${path}?${newParamsStr}`);
    },
    {
      deep: true,
      immediate: true
    }
  );
  return state;
}
module.exports = useUrlState;

==> vue-hooks-plus-1.7.4.tgz: package/lib/useUrlState/index.js <==
"use strict";
const qs = require("qs");
const vue = require("vue");
const index = require("../index");
const utils = require("../utils");
function encodeParams(value) {
  return qs.stringify(value);
}
function decodeParams(valueStr, detectNumber) {
  return qs.parse(valueStr, {
    // fix: 数组长度限制问题
    arrayLimit: 1e4,
    decoder(str, _, charset) {
      const strWithoutPlus = str.replace(/\+/g, " ");
      if (charset === "iso-8859-1") {
        return strWithoutPlus.replace(/%[0-9a-f]{2}/gi, unescape);
      }
      if (detectNumber && /^[+-]?\d+(\.\d+)?$/.test(str)) {
        return parseFloat(str);
      }
      const keywords = {
        true: true,
        false: false,
        null: null,
        undefined: void 0
      };
      if (str in keywords) {
        return keywords[str];
      }
      try {
        return decodeURIComponent(strWithoutPlus);
      } catch (e) {
        return strWithoutPlus;
      }
    }
  });
}
function useUrlState(initialState, options) {
  const routerPushFn = (options == null ? void 0 : options.routerPush) ? options.routerPush : (s) => location.hash = s;
  const { localStorageKey, detectNumber = true } = options ?? {};
  const [path, paramsStr] = location.hash.slice(1).split("?");
  const defaultState = (utils.isFunction(initialState) ? initialState() : initialState) ?? {};
  const state = localStorageKey ? index.useLocalStorageState(localStorageKey, {
    defaultValue: defaultState
  })[0] : vue.ref(defaultState);
  if (paramsStr) {
    try {
      const paramsValue = decodeParams(paramsStr, detectNumber);
      state.value = {
        ...defaultState,
        ...state.value,
        ...paramsValue
      };
    } catch {
      state.value = defaultState;
    }
  }
  if (initialState && Object.keys(initialState).length) {
    const newState = { ...initialState };
    for (const key in newState) {
      if (key in state.value) {
        newState[key] = state.value[key];
      }
    }
    state.value = newState;
  }
  vue.watch(
    state,
    () => {
      const newParamsStr = encodeParams(state.value);
      routerPushFn(`${path}?${newParamsStr}`);
    },
    {
      deep: true,
      immediate: true
    }
  );
  return state;
}
module.exports = useUrlState;
